==> haskell-th-reify-many-0.1.8-14-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-th-reify-many.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: th-reify-many
version: 0.1.8
id: th-reify-many-0.1.8-1SDhmGaYoHuAkUQIHoqsYB
key: th-reify-many-0.1.8-1SDhmGaYoHuAkUQIHoqsYB
license: BSD-3-Clause
maintainer: Michael Sloan <mgsloan at gmail>
author: Michael Sloan
stability: Experimental
homepage: http://github.com/mgsloan/th-reify-many
synopsis: Recurseively reify template haskell datatype info
description:
    @th-reify-many@ provides functions for recursively reifying top
    level declarations.  The main intended use case is for enumerating
    the names of datatypes reachable from an initial datatype, and
    passing these names to some function which generates instances.
category: Template Haskell
abi: 4b17557b8683a17b6612b6bf241bc350
exposed: True
exposed-modules:
    Language.Haskell.TH.ReifyMany
    Language.Haskell.TH.ReifyMany.Internal
import-dirs: /usr/lib/ghc-8.6.4/site-local/th-reify-many-0.1.8
library-dirs: /usr/lib/ghc-8.6.4/site-local/th-reify-many-0.1.8
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/th-reify-many-0.1.8
hs-libraries: HSth-reify-many-0.1.8-1SDhmGaYoHuAkUQIHoqsYB
depends:
    base-4.12.0.0 containers-0.6.0.1 mtl-2.2.2
    safe-0.3.17-43oyx4B630gDZMbTh3Ttji template-haskell-2.14.0.0
    th-expand-syns-0.4.4.0-Jqd7PPo0b5AIUFZ93VfrGv
haddock-interfaces: /usr/share/doc/haskell-th-reify-many/html/th-reify-many.haddock
haddock-html: /usr/share/doc/haskell-th-reify-many/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-th-reify-many-0.1.9-1-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-th-reify-many.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: th-reify-many
version: 0.1.9
id: th-reify-many-0.1.9-7yQcHE7smDBE8QUUw8G7iG
key: th-reify-many-0.1.9-7yQcHE7smDBE8QUUw8G7iG
license: BSD-3-Clause
maintainer: Michael Sloan <mgsloan at gmail>
author: Michael Sloan
stability: Experimental
homepage: http://github.com/mgsloan/th-reify-many
synopsis: Recurseively reify template haskell datatype info
description:
    @th-reify-many@ provides functions for recursively reifying top
    level declarations.  The main intended use case is for enumerating
    the names of datatypes reachable from an initial datatype, and
    passing these names to some function which generates instances.
category: Template Haskell
abi: 9c0d018909f955d64e46775c3a77d3c8
exposed: True
exposed-modules:
    Language.Haskell.TH.ReifyMany
    Language.Haskell.TH.ReifyMany.Internal
import-dirs: /usr/lib/ghc-8.6.4/site-local/th-reify-many-0.1.9
library-dirs: /usr/lib/ghc-8.6.4/site-local/th-reify-many-0.1.9
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/th-reify-many-0.1.9
hs-libraries: HSth-reify-many-0.1.9-7yQcHE7smDBE8QUUw8G7iG
depends:
    base-4.12.0.0 containers-0.6.0.1 mtl-2.2.2
    safe-0.3.17-43oyx4B630gDZMbTh3Ttji template-haskell-2.14.0.0
    th-expand-syns-0.4.4.0-Jqd7PPo0b5AIUFZ93VfrGv
haddock-interfaces: /usr/share/doc/haskell-th-reify-many/html/th-reify-many.haddock
haddock-html: /usr/share/doc/haskell-th-reify-many/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
